#!/usr/bin/env python

from moinformat import get_serialiser, make_parser, parse, serialise
from os.path import split
import sys

def main():
    dirname, progname = split(sys.argv[0])
    args = sys.argv[1:]

    l = filenames = []
    formats = []
    pagenames = []
    tree = False
    macros = False

    for arg in args:

        # Detect tree output.

        if arg == "--tree":
            tree = True

        # Detect macro evaluation.

        elif arg == "--macros":
            macros = True

        # Switch to collecting formats.

        elif arg == "--format":
            l = formats
            continue

        # Switch to collecting page names.

        elif arg == "--pagename":
            l = pagenames
            continue

        # Collect options and arguments.

        else:
            l.append(arg)

        # Collect filenames normally.

        l = filenames

    format = formats and formats[0] or "html"

    # Derive the page name from the filename if not specified.

    filename = filenames[0]
    pagename = pagenames and pagenames[0] or split(filename)[-1]

    f = open(filename)
    try:
        p = make_parser()
        d = parse(f.read(), p)

        if macros:
            p.evaluate_macros()

        if tree:
            print d.prettyprint()
        else:
            p.translate_links(format, pagename)
            print serialise(d, get_serialiser(format))
    finally:
        f.close()

if __name__ == "__main__":
    main()

# vim: tabstop=4 expandtab shiftwidth=4
